Skip to contents

Generate a Qualtrics Import File for the PID-5 (Full)

Usage

generate_qualtrics_pid5(
  file = "pid5_qualtrics.txt",
  block_name = "PID-5",
  id_prefix = "PID5",
  include_instructions = TRUE,
  breaks = 15
)

Arguments

file

Character string specifying the output file path.

block_name

Character string specifying the name of the block in Qualtrics.

id_prefix

Character string specifying the prefix for the question IDs.

include_instructions

Logical. If TRUE, includes instructions block.

breaks

Integer or NULL. The number of items to display before a page break.