Generate a REDCap Instrument ZIP File for the HiTOP-HSUM
Source:R/generate_redcap.R
generate_redcap_hitophsum.RdGenerates a REDCap-compatible data dictionary for the Hierarchical Taxonomy of Psychopathology - Substance Use Module (HiTOP-HSUM) and packages it into an Instrument ZIP file for easy uploading.
Usage
generate_redcap_hitophsum(
file = "hitophsum_redcap.zip",
form_name = "hitophsum_questionnaire",
required = TRUE
)Details
Importing (Uploading) Instruments into a REDCap Project:
Log in to your REDCap account and navigate to the desired project.
Click on the "Designer" link in the left menu bar under "Project Home and Design".
In the main page, under "Data Collection Instruments", look for the "Upload instrument ZIP" option and click the "Upload" button.
Click "Choose File", navigate to where you have the measure saved as a ZIP folder, and select the ZIP folder containing your instrument.
Click "Upload instrument ZIP" button to begin the import process.
Find the imported instrument in your list of measures and review for accuracy.
Test the instrument to ensure proper functionality within your project.