Add literal item text or clean scale names as attributes to data frame columns, making them readable by data viewers and reporting packages.
Usage
label_hitopsr(data, target = c("items", "scales"), prefix = "HSR_")Examples
# Attach item text as a `label` attribute to the raw item columns
labeled <- label_hitopsr(sim_hitopsr, target = "items", prefix = "hsr_")
attr(labeled$hsr_1, "label")
#> [1] "I preferred to stay home than to go to a party."