Add literal item text or clean scale names as attributes to data frame columns, making them readable by data viewers and reporting packages.
Usage
label_hitopsr(data, target = c("items", "scales"), prefix = "HSR_")Add literal item text or clean scale names as attributes to data frame columns, making them readable by data viewers and reporting packages.
label_hitopsr(data, target = c("items", "scales"), prefix = "HSR_")